==> CodeMirror-0.1.5.zip: CodeMirror/lang/ext/nb_NO.php <==
<?php
$lang['friendlyname'] = 'CodeMirror syntaksfremhevingsredigerer';
$lang['postinstall'] = 'CodeMirror modulen ble installert';
$lang['needpermission'] = 'Du trenger &#039;%s&#039; tillatelse for &aring; utf&oslash;re denne funksjonen.';
$lang['settingstab'] = 'Innstillinger';
$lang['savesettings'] = 'Lagre innstillinger';
$lang['settingssaved'] = 'Innstillinger lagret';
$lang['htmltest'] = 'HTML syntaks test';
$lang['csstest'] = 'CSS syntaks test';
$lang['phptest'] = 'PHP syntaks test';
$lang['examplesyntax'] = 'Syntaks &aring; teste med';
$lang['change'] = 'Endre...';
$lang['showlinenumbers'] = 'Vis linjenummer';
$lang['textwrapping'] = 'Bryt lange linjer';
$lang['help'] = '<strong>What does this module do?</strong>
<br/>
The CodeMirror module allows you to edit content, templates and stylesheets using a syntaxhighlighting editor inside your browser.
It can both replace a wysiwyg-module, and act standalone for template/stylesheet editing (only supported in CMSms 1.1+)
<br/><br/>
<strong>How do I use this module?</strong>
You simply install it, and choose it in your admin user preferences. Note, that if you use CMSms 1.1 or above you can
select CodeArea both as a WYSIWYG and as a syntax highlighting editor.';
$lang['utmz'] = '156861353.1266068713.2376.50.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms support';
$lang['utma'] = '156861353.179052623084110100.1210423577.1266157561.1266187742.2383';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmb'] = '156861353.2.10.1266187742';
$lang['utmc'] = '156861353';
?>

==> CodeMirror-2.0.1.zip: CodeMirror/lang/ext/nb_NO.php <==
<?php
$lang['friendlyname'] = 'CodeMirror syntaksfremhevingsredigerer';
$lang['postinstall'] = 'CodeMirror modulen ble installert';
$lang['needpermission'] = 'Du trenger &#039;%s&#039; tillatelse for &aring; utf&oslash;re denne funksjonen.';
$lang['settingstab'] = 'Innstillinger';
$lang['savesettings'] = 'Lagre innstillinger';
$lang['settingssaved'] = 'Innstillinger lagret';
$lang['htmltest'] = 'HTML syntaks test';
$lang['csstest'] = 'CSS syntaks test';
$lang['phptest'] = 'PHP syntaks test';
$lang['jstest'] = 'JavaScript syntakstest';
$lang['examplesyntax'] = 'Syntaks &aring; teste med';
$lang['change'] = 'Endre...';
$lang['showlinenumbers'] = 'Vis linjenummer';
$lang['textwrapping'] = 'Bryt lange linjer';
$lang['automatchparens'] = 'Automatiske paranteser';
$lang['tabhandling'] = 'Hvordan skal trykk av TAB-tasten h&aring;nteres';
$lang['tabdefault'] = 'La nettleseren avgj&oslash;re';
$lang['tabindent'] = 'Lag innrykk';
$lang['tabspaces'] = 'Sett inn mellomrom';
$lang['tabshift'] = 'Sender til h&oslash;yre, shift-TAB sender til venstre';
$lang['cssadditions'] = 'CodeMirror-css tillegg.';
$lang['help'] = '<strong>What does this module do?</strong>
<br/>
The CodeMirror module allows you to edit content, templates and stylesheets using a syntaxhighlighting editor inside your browser.
It can both replace a wysiwyg-module, and act standalone for template/stylesheet editing (only supported in CMSms 1.1+)
<br/><br/>
<strong>How do I use this module?</strong>
You simply install it, and choose it in your admin user preferences. Note, that if you use CMSms 1.1 or above you can
select CodeArea both as a WYSIWYG and as a syntax highlighting editor.';
$lang['utmz'] = '156861353.1300226369.3692.81.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/feature_request/list/6';
$lang['utma'] = '156861353.179052623084110100.1210423577.1302044019.1302118822.3753';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
